/************************************************************************
*	Project		:	Gumsense											*
*	Module		:	Controller											*
*	Date		:	01 February 2005									*
*	Version		:	1.00												*
*	Filename	:	main.c												*
*	Programmer	:	Royan H. L. Ong										*
*	Frequency	:	10MHz												*
*	Processor	:	PIC16F876A (NOTE: "A" version must be used!			*
*																		*
************************************************************************/

#include "define.h"

//global variables
ULONG MS_COUNTER;
UINT DIGITAL_IO;

//local function prototypes (others)
void StartUp(void);
void TMR2Init(void);
void interrupt ISR(void);

//***** Start of Code ***************************************************
void main(void)
	{
	StartUp();											//initialize system

	for(;;)												//main loop
		{
		if(SSPIF == 1) I2CSlaveExec();					//process I2C
		}
	}

void StartUp(void)
	{
	TRISA4 = 0;	LED_OFF;								//debug LED
	MS_COUNTER = 0; DIGITAL_IO = 0x0000;

	ADCInit();											//initialise modules
	I2CSlaveInit();
	TMR2Init();
	
	INTCON |= 0xC0;										//enable interrupts
	}

void TMR2Init(void)										//1ms tick 
	{
	PR2 = 124;											//value for 1ms @ 10MHz
//	PR2 = 49;											//value for 1ms @ 4MHz
	T2CON = 0x25;										//pre = 1:4, post = 1:10 (1/80th Fosc)
	TMR2IF = 0;
	TMR2IE = 1;											//1ms tick interrupt
	}

void interrupt ISR(void)
	{
	if((TMR2IF == 1) && (TMR2IE == 1))					//1 ms tick
		{
		TMR2IF = 0;										//reset flag
		MS_COUNTER++;									//increment ms counter

		if((MS_COUNTER > I2C_TIMEOUT) && (I2C_IDLE == 0))
			{											//if I2C timeout occur
			SSPIF = 0;									//reset interrupt flag
			SSPEN = 0; SSPEN = 1;						//reset I2C module
			I2C_IDLE = 1;								//I2C module is idle
			}
		}
	}
//***** End of Code *****************************************************
